# Copyright (C) 2005 by Aaron Bentley

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
import errno
import os
import shutil
from bzrlib.branch import Branch

def is_detrius(subp):
    return subp.endswith('.THIS') or subp.endswith('.BASE') or\
        subp.endswith('.OTHER') or subp.endswith('~')

def iter_deletables(tree, unknowns=True, ignored=False, detrius=False):
    """Iterate through files that may be deleted"""
    for subp in tree.extras():
        if is_detrius(subp):
            yield tree.abspath(subp), subp
        if tree.is_ignored(subp):
            if ignored:
                yield tree.abspath(subp), subp
        else:
            if unknowns:
                yield tree.abspath(subp), subp


def clean_tree(deletables, dry_run=False):
    """Delete files in the deletables iterable"""
    printed_once = False
    for path, subp in deletables:
        if not printed_once:
            print "deleting paths:"
            printed_once = True
        print ' ', subp
        if not dry_run:
            if os.path.isdir(path):
                shutil.rmtree(path)
            else:
                os.unlink(path)
